Skip to main contentCrate libcros
Source pub use logging::Logger;pub use keyval::*;
- cmdline
- Various high-level functions to read the cmdline of the currently-running Linux kernel.
(assuming you have read permissions to
/proc/cmdline) - crypto
- Basic cryptography functions
- diskutils
- High-level functions to interact with a GPT-formatted disk. (Including ChromeOS disks)
- execute
- Easy-to-use functions to execute commands
- fs
- Filesystem-related APIs\
- gsc
- Send/receive vendor commands to/from the GSC (Google Security Chip) / TPM.
- keyval
- Easy-to-use key=value system with types.
- libargs
- Lightweight argument parser
- libc
- Various system calls.
- logging
- Easy-to-use logging API
- structs
- Commonly-used structs
- sysinfo
- High-level functions to get information about a Chrome device
- tlcl
- A lightweight TPM2 library. Based on vboot’s Tlcl library.
- ui
- Basic drawing functions for TUIs
- LOG
- Info log.
- LOG_DBG
- Debug log when verbose is enabled.
- LOG_FATAL
- Fatal log and exit.
- LOG_FATAL_NOEXIT
- Fatal log without exit.
- tpm_nv_read
- Macro to reduce boilerplate